==> jc-1.4.0.tar.gz: soot/jimple/internal/JReturnVoidStmt.h <==
// public class soot.jimple.internal.JReturnVoidStmt

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 2492f1f7a753b788 soot_AbstractUnit
// @dep_class b3c0d2cd30f6acdd soot_jimple_internal_AbstractStmt
// @dep_class a5dd115f95abf92b soot_jimple_internal_JReturnVoidStmt
// @dep_class 6ddedfee878f127 soot_tagkit_AbstractHost

// header file dependencies
// @dep_header soot_jimple_internal_AbstractStmt

#include "soot/jimple/internal/AbstractStmt.h"

#ifndef _JC_soot_jimple_internal_JReturnVoidStmt_H_
#define _JC_soot_jimple_internal_JReturnVoidStmt_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_List$object;
struct _jc_soot_UnitPrinter$object;
struct _jc_soot_jimple_JimpleToBafContext$object;
struct _jc_soot_util_Switch$object;

// Typedefs
typedef struct _jc_soot_jimple_internal_JReturnVoidStmt$sub_refs	_jc_soot_jimple_internal_JReturnVoidStmt$sub_refs;
typedef struct _jc_soot_jimple_internal_JReturnVoidStmt$sub_nonrefs	_jc_soot_jimple_internal_JReturnVoidStmt$sub_nonrefs;
typedef struct _jc_soot_jimple_internal_JReturnVoidStmt$refs	_jc_soot_jimple_internal_JReturnVoidStmt$refs;
typedef struct _jc_soot_jimple_internal_JReturnVoidStmt$nonrefs	_jc_soot_jimple_internal_JReturnVoidStmt$nonrefs;
typedef struct _jc_soot_jimple_internal_JReturnVoidStmt$object	_jc_soot_jimple_internal_JReturnVoidStmt$object;

typedef const struct _jc_soot_jimple_internal_JReturnVoidStmt$vmethods	_jc_soot_jimple_internal_JReturnVoidStmt$vmethods;
typedef const struct _jc_soot_jimple_internal_JReturnVoidStmt$vtable	_jc_soot_jimple_internal_JReturnVoidStmt$vtable;
typedef const struct _jc_soot_jimple_internal_JReturnVoidStmt$vtype	_jc_soot_jimple_internal_JReturnVoidStmt$vtype;

// Constructors
extern void _jc_soot_jimple_internal_JReturnVoidStmt$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_internal_JReturnVoidStmt$object *);

// Virtual methods
extern void _jc_soot_jimple_internal_JReturnVoidStmt$method$apply$cd67f53165014a6d(_jc_env *, struct _jc_soot_jimple_internal_JReturnVoidStmt$object *, struct _jc_object *);
extern jboolean _jc_soot_jimple_internal_JReturnVoidStmt$method$branches$b1fa209d4c0e0b15(_jc_env *, struct _jc_soot_jimple_internal_JReturnVoidStmt$object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_internal_JReturnVoidStmt$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_internal_JReturnVoidStmt$object *);
extern void _jc_soot_jimple_internal_JReturnVoidStmt$method$convertToBaf$0357e46cf55b475a(_jc_env *, struct _jc_soot_jimple_internal_JReturnVoidStmt$object *, struct _jc_soot_jimple_JimpleToBafContext$object *, struct _jc_object *);
extern jboolean _jc_soot_jimple_internal_JReturnVoidStmt$method$fallsThrough$09e8b0d6b0c9d1bf(_jc_env *, struct _jc_soot_jimple_internal_JReturnVoidStmt$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_internal_JReturnVoidStmt$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_internal_JReturnVoidStmt$object *);
extern void _jc_soot_jimple_internal_JReturnVoidStmt$method$toString$49ce0d4a4e59c2a6(_jc_env *, struct _jc_soot_jimple_internal_JReturnVoidStmt$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_internal_JReturnVoidStmt$method_info$apply$cd67f53165014a6d;
extern _jc_method _jc_soot_jimple_internal_JReturnVoidStmt$method_info$branches$b1fa209d4c0e0b15;
extern _jc_method _jc_soot_jimple_internal_JReturnVoidStmt$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_internal_JReturnVoidStmt$method_info$convertToBaf$0357e46cf55b475a;
extern _jc_method _jc_soot_jimple_internal_JReturnVoidStmt$method_info$fallsThrough$09e8b0d6b0c9d1bf;
extern _jc_method _jc_soot_jimple_internal_JReturnVoidStmt$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_soot_jimple_internal_JReturnVoidStmt$method_info$toString$49ce0d4a4e59c2a6;

// Virtual methods structure
struct _jc_soot_jimple_internal_JReturnVoidStmt$vmethods {
	void	(*apply$cd67f53165014a6d)(_jc_env *, struct _jc_soot_jimple_internal_JReturnVoidStmt$object *, struct _jc_object *);
	jboolean	(*branches$b1fa209d4c0e0b15)(_jc_env *, struct _jc_soot_jimple_internal_JReturnVoidStmt$object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_internal_JReturnVoidStmt$object *);
	void	(*convertToBaf$0357e46cf55b475a)(_jc_env *, struct _jc_soot_jimple_internal_JReturnVoidStmt$object *, struct _jc_soot_jimple_JimpleToBafContext$object *, struct _jc_object *);
	jboolean	(*fallsThrough$09e8b0d6b0c9d1bf)(_jc_env *, struct _jc_soot_jimple_internal_JReturnVoidStmt$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_internal_JReturnVoidStmt$object *);
	void	(*toString$49ce0d4a4e59c2a6)(_jc_env *, struct _jc_soot_jimple_internal_JReturnVoidStmt$object *, struct _jc_object *);
};

// Vtable
struct _jc_soot_jimple_internal_JReturnVoidStmt$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_AbstractHost$vmethods	soot_tagkit_AbstractHost;
	_jc_soot_AbstractUnit$vmethods	soot_AbstractUnit;
	_jc_soot_jimple_internal_AbstractStmt$vmethods	soot_jimple_internal_AbstractStmt;
	_jc_soot_jimple_internal_JReturnVoidStmt$vmethods	soot_jimple_internal_JReturnVoidStmt;
};

// Vtype
struct _jc_soot_jimple_internal_JReturnVoidStmt$vtype {
	_jc_type			type;
	_jc_soot_jimple_internal_JReturnVoidStmt$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_internal_JReturnVoidStmt$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_internal_JReturnVoidStmt$refs {
    _jc_soot_jimple_internal_JReturnVoidStmt$sub_refs	soot_jimple_internal_JReturnVoidStmt;
    _jc_soot_jimple_internal_AbstractStmt$sub_refs	soot_jimple_internal_AbstractStmt;
    _jc_soot_AbstractUnit$sub_refs	soot_AbstractUnit;
    _jc_soot_tagkit_AbstractHost$sub_refs	soot_tagkit_AbstractHost;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_internal_JReturnVoidStmt$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_internal_JReturnVoidStmt$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_AbstractHost$sub_nonrefs	soot_tagkit_AbstractHost;
    _jc_soot_AbstractUnit$sub_nonrefs	soot_AbstractUnit;
    _jc_soot_jimple_internal_AbstractStmt$sub_nonrefs	soot_jimple_internal_AbstractStmt;
    _jc_soot_jimple_internal_JReturnVoidStmt$sub_nonrefs	soot_jimple_internal_JReturnVoidStmt;
};

// Object instance structure
struct _jc_soot_jimple_internal_JReturnVoidStmt$object {
	_jc_soot_jimple_internal_JReturnVoidStmt$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_internal_JReturnVoidStmt$vtype	*vtype;
	_jc_soot_jimple_internal_JReturnVoidStmt$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_internal_JReturnVoidStmt$vtype _jc_soot_jimple_internal_JReturnVoidStmt$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_internal_JReturnVoidStmt, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_internal_JReturnVoidStmt$class_object;

#endif	/* _JC_soot_jimple_internal_JReturnVoidStmt_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/internal/JReturnVoidStmt.h <==
// public class soot.jimple.internal.JReturnVoidStmt

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 2492f1f7a753b788 soot_AbstractUnit
// @dep_class b3c0d2cd30f6acdd soot_jimple_internal_AbstractStmt
// @dep_class a5dd115f95abf92b soot_jimple_internal_JReturnVoidStmt
// @dep_class 6ddedfee878f127 soot_tagkit_AbstractHost

// header file dependencies
// @dep_header soot_jimple_internal_AbstractStmt

#include "soot/jimple/internal/AbstractStmt.h"

#ifndef _JC_soot_jimple_internal_JReturnVoidStmt_H_
#define _JC_soot_jimple_internal_JReturnVoidStmt_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_List$object;
struct _jc_soot_UnitPrinter$object;
struct _jc_soot_jimple_JimpleToBafContext$object;
struct _jc_soot_util_Switch$object;

// Typedefs
typedef struct _jc_soot_jimple_internal_JReturnVoidStmt$sub_refs	_jc_soot_jimple_internal_JReturnVoidStmt$sub_refs;
typedef struct _jc_soot_jimple_internal_JReturnVoidStmt$sub_nonrefs	_jc_soot_jimple_internal_JReturnVoidStmt$sub_nonrefs;
typedef struct _jc_soot_jimple_internal_JReturnVoidStmt$refs	_jc_soot_jimple_internal_JReturnVoidStmt$refs;
typedef struct _jc_soot_jimple_internal_JReturnVoidStmt$nonrefs	_jc_soot_jimple_internal_JReturnVoidStmt$nonrefs;
typedef struct _jc_soot_jimple_internal_JReturnVoidStmt$object	_jc_soot_jimple_internal_JReturnVoidStmt$object;

typedef const struct _jc_soot_jimple_internal_JReturnVoidStmt$vmethods	_jc_soot_jimple_internal_JReturnVoidStmt$vmethods;
typedef const struct _jc_soot_jimple_internal_JReturnVoidStmt$vtable	_jc_soot_jimple_internal_JReturnVoidStmt$vtable;
typedef const struct _jc_soot_jimple_internal_JReturnVoidStmt$vtype	_jc_soot_jimple_internal_JReturnVoidStmt$vtype;

// Constructors
extern void _jc_soot_jimple_internal_JReturnVoidStmt$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_internal_JReturnVoidStmt$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_internal_JReturnVoidStmt$method$apply$cd67f53165014a6d(_jc_env *, struct _jc_soot_jimple_internal_JReturnVoidStmt$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_jimple_internal_JReturnVoidStmt$method$branches$b1fa209d4c0e0b15(_jc_env *, struct _jc_soot_jimple_internal_JReturnVoidStmt$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_internal_JReturnVoidStmt$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_internal_JReturnVoidStmt$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_internal_JReturnVoidStmt$method$convertToBaf$0357e46cf55b475a(_jc_env *, struct _jc_soot_jimple_internal_JReturnVoidStmt$object *, struct _jc_soot_jimple_JimpleToBafContext$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_jimple_internal_JReturnVoidStmt$method$fallsThrough$09e8b0d6b0c9d1bf(_jc_env *, struct _jc_soot_jimple_internal_JReturnVoidStmt$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_internal_JReturnVoidStmt$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_internal_JReturnVoidStmt$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_internal_JReturnVoidStmt$method$toString$49ce0d4a4e59c2a6(_jc_env *, struct _jc_soot_jimple_internal_JReturnVoidStmt$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_internal_JReturnVoidStmt$method_info$apply$cd67f53165014a6d;
extern _jc_method _jc_soot_jimple_internal_JReturnVoidStmt$method_info$branches$b1fa209d4c0e0b15;
extern _jc_method _jc_soot_jimple_internal_JReturnVoidStmt$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_internal_JReturnVoidStmt$method_info$convertToBaf$0357e46cf55b475a;
extern _jc_method _jc_soot_jimple_internal_JReturnVoidStmt$method_info$fallsThrough$09e8b0d6b0c9d1bf;
extern _jc_method _jc_soot_jimple_internal_JReturnVoidStmt$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_soot_jimple_internal_JReturnVoidStmt$method_info$toString$49ce0d4a4e59c2a6;

// Virtual methods structure
struct _jc_soot_jimple_internal_JReturnVoidStmt$vmethods {
	void	(*apply$cd67f53165014a6d)(_jc_env *, struct _jc_soot_jimple_internal_JReturnVoidStmt$object *, struct _jc_object *) _JC_JCNI_ATTR;
	jboolean	(*branches$b1fa209d4c0e0b15)(_jc_env *, struct _jc_soot_jimple_internal_JReturnVoidStmt$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_internal_JReturnVoidStmt$object *) _JC_JCNI_ATTR;
	void	(*convertToBaf$0357e46cf55b475a)(_jc_env *, struct _jc_soot_jimple_internal_JReturnVoidStmt$object *, struct _jc_soot_jimple_JimpleToBafContext$object *, struct _jc_object *) _JC_JCNI_ATTR;
	jboolean	(*fallsThrough$09e8b0d6b0c9d1bf)(_jc_env *, struct _jc_soot_jimple_internal_JReturnVoidStmt$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_internal_JReturnVoidStmt$object *) _JC_JCNI_ATTR;
	void	(*toString$49ce0d4a4e59c2a6)(_jc_env *, struct _jc_soot_jimple_internal_JReturnVoidStmt$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_internal_JReturnVoidStmt$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_AbstractHost$vmethods	soot_tagkit_AbstractHost;
	_jc_soot_AbstractUnit$vmethods	soot_AbstractUnit;
	_jc_soot_jimple_internal_AbstractStmt$vmethods	soot_jimple_internal_AbstractStmt;
	_jc_soot_jimple_internal_JReturnVoidStmt$vmethods	soot_jimple_internal_JReturnVoidStmt;
};

// Vtype
struct _jc_soot_jimple_internal_JReturnVoidStmt$vtype {
	_jc_type			type;
	_jc_soot_jimple_internal_JReturnVoidStmt$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_internal_JReturnVoidStmt$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_internal_JReturnVoidStmt$refs {
    _jc_soot_jimple_internal_JReturnVoidStmt$sub_refs	soot_jimple_internal_JReturnVoidStmt;
    _jc_soot_jimple_internal_AbstractStmt$sub_refs	soot_jimple_internal_AbstractStmt;
    _jc_soot_AbstractUnit$sub_refs	soot_AbstractUnit;
    _jc_soot_tagkit_AbstractHost$sub_refs	soot_tagkit_AbstractHost;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_internal_JReturnVoidStmt$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_internal_JReturnVoidStmt$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_AbstractHost$sub_nonrefs	soot_tagkit_AbstractHost;
    _jc_soot_AbstractUnit$sub_nonrefs	soot_AbstractUnit;
    _jc_soot_jimple_internal_AbstractStmt$sub_nonrefs	soot_jimple_internal_AbstractStmt;
    _jc_soot_jimple_internal_JReturnVoidStmt$sub_nonrefs	soot_jimple_internal_JReturnVoidStmt;
};

// Object instance structure
struct _jc_soot_jimple_internal_JReturnVoidStmt$object {
	_jc_soot_jimple_internal_JReturnVoidStmt$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_internal_JReturnVoidStmt$vtype	*vtype;
	_jc_soot_jimple_internal_JReturnVoidStmt$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_internal_JReturnVoidStmt$vtype _jc_soot_jimple_internal_JReturnVoidStmt$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_internal_JReturnVoidStmt, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_internal_JReturnVoidStmt$class_object;

#endif	/* _JC_soot_jimple_internal_JReturnVoidStmt_H_ */
